@@ -150,9 +150,10 @@ AbstractResource::State PackageKitResource::state()
         return Broken;
 }
 
-void PackageKitResource::resetPackageIds()
+void PackageKitResource::setPackages(const QMap<PackageKit::Transaction::Info, QStringList> &packages)
 {
-    m_packages.clear();
+    m_packages = packages;
+    emit stateChanged();
 }
 
 void PackageKitResource::addPackageId(PackageKit::Transaction::Info info, const QString &packageId, const QString &/*summary*/)
@@ -290,18 +291,20 @@ void PackageKitResource::fetchDetails()
     m_details.insert("fetching", true);//we add an entry so it's not re-fetched.
 
     PackageKit::Transaction* t = PackageKit::Daemon::getDetails(availablePackageId());
-    connect(t, SIGNAL(details(PackageKit::Details)), this, SLOT(setDetails(PackageKit::Details)));
+    connect(t, &PackageKit::Transaction::details, this, &PackageKitResource::setDetails);
     connect(t, &PackageKit::Transaction::errorCode, this, [](PackageKit::Transaction::Error, const QString& msg){ qWarning() << "error fetching details" << msg; });
 }
 
 void PackageKitResource::setDetails(const PackageKit::Details & details)
 {
-    if (!m_packages.value(PackageKit::Transaction::InfoAvailable).contains(details.packageId()))
+    const bool ourDetails = details.packageId() == availablePackageId();
+    if (!ourDetails)
         return;
 
     m_details = details;
-
     emit stateChanged();
+
+    backend()->allDataChanged();
 }
 
 void PackageKitResource::fetchChangelog()
