@@ -220,11 +220,11 @@ void MainWindow::markUpgrade()
     m_backend->markPackagesForUpgrade();
 
     if (m_backend-> markedPackages().isEmpty()) {
-        QString text = i18nc("@label", "Unable to mark upgrades. The "
-                             "available upgrades may require new packages to "
-                             "be installed or removed. You may wish to try "
-                             "a full upgrade by clicking the <interface>Full "
-                             "Upgrade</interface> button.");
+        QString text = xi18nc("@label", "Unable to mark upgrades. The "
+                              "available upgrades may require new packages to "
+                              "be installed or removed. You may wish to try "
+                              "a full upgrade by clicking the <interface>Full "
+                              "Upgrade</interface> button.");
         QString title = i18nc("@title:window", "Unable to Mark Upgrades");
         KMessageBox::information(this, text, title);
     } else {
